@@ -102,6 +102,7 @@
   N_("split pane")
   N_("spin button")
   N_("statusbar")
+  N_("switch")
   N_("table")
   N_("table cell")
   N_("table column header")
@@ -616,7 +617,7 @@ add_accessible_from_iter (DBusMessageIter *iter)
     {
       /* Get index in parent */
       dbus_message_iter_get_basic (&iter_struct, &index);
-      if (index >= 0 && accessible->accessible_parent)
+      if (index >= 0 && index < 65536 && accessible->accessible_parent)
         {
           AtspiAccessible *old_child = NULL;
           if (index >= accessible->accessible_parent->children->len)
@@ -2043,7 +2044,14 @@ atspi_role_get_localized_name (AtspiRole role)
 
   _gettext_initialization ();
 
-  raw_name = atspi_role_get_name (role);
+  switch (role)
+    {
+    case ATSPI_ROLE_EDITBAR:
+      raw_name = g_strdup ("edit bar");
+      break;
+    default:
+      raw_name = atspi_role_get_name (role);
+    }
   translated_name = dgettext (GETTEXT_PACKAGE, raw_name);
   if (translated_name != raw_name)
     {
