@@ -33,11 +33,31 @@
 #include <sys/wait.h>
 #include <unistd.h>
 
+typedef enum
+{
+  FIXTURE_STATE_WAITING_FOR_CHILD,
+  FIXTURE_STATE_CHILD_ACQUIRED,
+} FixtureState;
+
+typedef struct
+{
+  FixtureState state;
+
+  char *name_to_claim;
+
+  guint wait_for_test_app_timeout;
+  gboolean test_app_timed_out;
+  pid_t child_pid;
+
+  AtspiAccessible *root_obj;
+} TestAppFixture;
+
 extern pid_t child_pid;
 
-void run_app (const char *file_name);
-AtspiAccessible *get_root_obj (const char *file_name);
-void terminate_app (void);
-void clean_exit_on_fail ();
+void fixture_listener_init (void);
+void fixture_listener_destroy (void);
+void fixture_setup (TestAppFixture *fixture, gconstpointer user_data);
+void fixture_teardown (TestAppFixture *fixture, gconstpointer user_data);
 
+void check_name (AtspiAccessible *accessible, const char *expected_name);
 #endif /* _ATK_TEST_UTIL_H */
